@@ -20,5 +20,5 @@ rm -f fileglancer/_version.py || true
 clean_dir ".pixi/envs" || true
 clean_dir ".pixi/solve-group-envs" || true
 clean_dir "fileglancer/labextension" || true
-clean_dir "node_modules" || true
+clean_dir "frontend/node_modules" || true
 echo "Cleaned up dev environment."
