@@ -3,6 +3,7 @@ import sys
 import pwd
 import grp
 import json
+import secrets
 from datetime import datetime, timedelta, timezone, UTC
 from functools import cache
 from pathlib import Path as PathLib
@@ -30,7 +31,7 @@ from fileglancer import auth
 from fileglancer.model import *
 from fileglancer.settings import get_settings
 from fileglancer.issues import create_jira_ticket, get_jira_ticket_details, delete_jira_ticket
-from fileglancer.utils import slugify_path, format_timestamp, guess_content_type, parse_range_header
+from fileglancer.utils import format_timestamp, guess_content_type, parse_range_header
 from fileglancer.user_context import UserContext, EffectiveUserContext, CurrentUserContext
 from fileglancer.filestore import Filestore
 from fileglancer.log import AccessLogMiddleware
@@ -54,7 +55,7 @@ def _read_version() -> str:
             current_file = os.path.abspath(__file__)
             current_dir = os.path.dirname(current_file)
             project_root = os.path.dirname(current_dir)
-            package_json_path = os.path.join(project_root, "package.json")
+            package_json_path = os.path.join(project_root, "frontend", "package.json")
 
             with open(package_json_path, "r") as f:
                 data = json.load(f)
@@ -122,14 +123,8 @@ def create_app(settings):
     # Initialize OAuth client for OKTA
     oauth = auth.setup_oauth(settings)
 
-    @cache
-    def _get_fsp_names_to_mount_paths() -> Dict[str, str]:
-        if settings.file_share_mounts:
-            return {slugify_path(path): path for path in settings.file_share_mounts}
-        else:
-            with db.get_db_session(settings.db_url) as session:
-                return {fsp.name: fsp.mount_path for fsp in db.get_all_paths(session)}
-
+    # Define ui_dir for serving static files and SPA
+    ui_dir = PathLib(__file__).parent / "ui"
 
     def _get_user_context(username: str) -> UserContext:
         if settings.use_access_flags:
@@ -147,11 +142,12 @@ def create_app(settings):
             if proxied_path.sharing_name != sharing_name:
                 return get_error_response(400, "InvalidArgument", f"Sharing name mismatch for sharing key {sharing_key}", sharing_name), None
 
-            fsp_names_to_mount_paths = _get_fsp_names_to_mount_paths()
-            if proxied_path.fsp_name not in fsp_names_to_mount_paths:
+            fsp = db.get_file_share_path(session, proxied_path.fsp_name)
+            if not fsp:
                 return get_error_response(400, "InvalidArgument", f"File share path {proxied_path.fsp_name} not found", sharing_name), None
-            fsp_mount_path = fsp_names_to_mount_paths[proxied_path.fsp_name]
-            mount_path = f"{fsp_mount_path}/{proxied_path.path}"
+            # Expand ~ to user's home directory before constructing the mount path
+            expanded_mount_path = os.path.expanduser(fsp.mount_path)
+            mount_path = f"{expanded_mount_path}/{proxied_path.path}"
             return FileProxyClient(proxy_kwargs={'target_name': sharing_name}, path=mount_path), _get_user_context(proxied_path.username)
 
 
@@ -167,24 +163,31 @@ def create_app(settings):
             import re
             return re.sub(r'(://[^:]+:)[^@]+(@)', r'\1****\2', url)
 
-        logger.info(f"Settings:")
-        logger.info(f"  log_level: {settings.log_level}")
-        logger.info(f"  db_url: {mask_password(settings.db_url)}")
+        logger.debug(f"Settings:")
+        logger.debug(f"  log_level: {settings.log_level}")
+        logger.debug(f"  db_url: {mask_password(settings.db_url)}")
         if settings.db_admin_url:
-            logger.info(f"  db_admin_url: {mask_password(settings.db_admin_url)}")
-        logger.info(f"  use_access_flags: {settings.use_access_flags}")
-        logger.info(f"  atlassian_url: {settings.atlassian_url}")
+            logger.debug(f"  db_admin_url: {mask_password(settings.db_admin_url)}")
+        logger.debug(f"  use_access_flags: {settings.use_access_flags}")
+        logger.debug(f"  atlassian_url: {settings.atlassian_url}")
 
         # Initialize database (run migrations once at startup)
-        logger.info("Initializing database...")
         db.initialize_database(settings.db_url)
 
+        # Mount static assets (CSS, JS, images) at /fg/assets
+        assets_dir = ui_dir / "assets"
+        if assets_dir.exists():
+            app.mount("/fg/assets", StaticFiles(directory=str(assets_dir)), name="assets")
+            logger.debug(f"Mounted static assets at /fg/assets from {assets_dir}")
+        else:
+            logger.warning(f"Assets directory not found at {assets_dir}")
+
         # Check for notifications file at startup
         notifications_file = os.path.join(os.getcwd(), "notifications.yaml")
         if os.path.exists(notifications_file):
-            logger.info(f"Notifications file found: {notifications_file}")
+            logger.debug(f"Notifications file found: {notifications_file}")
         else:
-            logger.info(f"No notifications file found at {notifications_file}")
+            logger.debug(f"No notifications file found at {notifications_file}")
 
         logger.info(f"Server ready")
         yield
@@ -197,6 +200,11 @@ def create_app(settings):
     # This logs HTTP access information with authenticated username
     app.add_middleware(AccessLogMiddleware, settings=settings)
 
+    # Generate random session_secret_key if not configured
+    if settings.session_secret_key is None:
+        settings.session_secret_key = secrets.token_urlsafe(32)
+        logger.warning("Generated random secret key. Set session_secret_key in your config to enable persistent sessions.")
+
     # Add SessionMiddleware for OAuth state management
     # This is required by authlib for the OAuth flow
     app.add_middleware(
@@ -217,15 +225,6 @@ def create_app(settings):
         expose_headers=["Range", "Content-Range"],
     )
 
-    # Mount static assets (CSS, JS, images) at /fg/assets
-    ui_dir = PathLib(__file__).parent / "ui"
-    assets_dir = ui_dir / "assets"
-    if assets_dir.exists():
-        app.mount("/fg/assets", StaticFiles(directory=str(assets_dir)), name="assets")
-        logger.info(f"Mounted static assets at /fg/assets from {assets_dir}")
-    else:
-        logger.warning(f"Assets directory not found at {assets_dir}")
-
 
     @app.exception_handler(StarletteHTTPException)
     async def http_exception_handler(request, exc):
@@ -297,6 +296,7 @@ def create_app(settings):
                     username=username,
                     email=email,
                     expires_at=expires_at,
+                    session_secret_key=settings.session_secret_key,
                     okta_access_token=token.get('access_token'),
                     okta_id_token=id_token
                 )
@@ -339,6 +339,36 @@ def create_app(settings):
         return redirect_response
 
 
+    @app.get("/api/auth/cli-login", include_in_schema=False,
+             description="Auto-login endpoint for CLI users")
+    async def cli_login(request: Request, session_id: str):
+        """Auto-login for CLI users - sets session cookie and redirects to browse page"""
+
+        # Only allow this endpoint when running in CLI mode
+        if not settings.cli_mode:
+            raise HTTPException(status_code=404, detail="Not found")
+
+        # Verify session exists in database
+        with db.get_db_session(settings.db_url) as session:
+            user_session = db.get_session_by_id(session, session_id)
+
+            if not user_session:
+                raise HTTPException(status_code=401, detail="Invalid session")
+
+            # Access username while still in session context
+            username = user_session.username
+
+        # Create redirect response to browse page
+        redirect_response = RedirectResponse(url="/fg/browse")
+
+        # Set session cookie
+        auth.create_session_cookie(redirect_response, session_id, settings)
+
+        logger.info(f"User {username} auto-logged in via CLI")
+
+        return redirect_response
+
+
     @app.get("/api/auth/status", description="Check authentication status")
     async def auth_status(request: Request):
         """Check if user is authenticated"""
@@ -360,32 +390,9 @@ def create_app(settings):
     @app.get("/api/file-share-paths", response_model=FileSharePathResponse,
              description="Get all file share paths from the database")
     async def get_file_share_paths() -> List[FileSharePath]:
-        file_share_mounts = settings.file_share_mounts
-        if file_share_mounts:
-            paths = [FileSharePath(
-                name=slugify_path(path),
-                zone='Local',
-                group='local',
-                storage='local',
-                mount_path=path,
-                mac_path=path,
-                windows_path=path,
-                linux_path=path,
-            ) for path in file_share_mounts]
-        else:
-            with db.get_db_session(settings.db_url) as session:
-                paths = [FileSharePath(
-                    name=path.name,
-                    zone=path.zone,
-                    group=path.group,
-                    storage=path.storage,
-                    mount_path=path.mount_path,
-                    mac_path=path.mac_path,
-                    windows_path=path.windows_path,
-                    linux_path=path.linux_path,
-                ) for path in db.get_all_paths(session)]
-
-        return FileSharePathResponse(paths=paths)
+        with db.get_db_session(settings.db_url) as session:
+            paths = db.get_file_share_paths(session)
+            return FileSharePathResponse(paths=paths)
 
 
     @app.get("/api/external-buckets", response_model=ExternalBucketResponse,
@@ -393,7 +400,7 @@ def create_app(settings):
     async def get_external_buckets() -> ExternalBucketResponse:
         with db.get_db_session(settings.db_url) as session:
             buckets = [_convert_external_bucket(bucket) for bucket in db.get_external_buckets(session)]
-        return ExternalBucketResponse(buckets=buckets)
+            return ExternalBucketResponse(buckets=buckets)
 
 
     @app.get("/api/external-buckets/{fsp_name}", response_model=ExternalBucketResponse,
@@ -401,7 +408,7 @@ def create_app(settings):
     async def get_external_buckets(fsp_name: str) -> ExternalBucket:
         with db.get_db_session(settings.db_url) as session:
             buckets = [_convert_external_bucket(bucket) for bucket in db.get_external_buckets(session, fsp_name)]
-        return ExternalBucketResponse(buckets=buckets)
+            return ExternalBucketResponse(buckets=buckets)
 
 
     @app.get("/api/notifications", response_model=NotificationResponse,
@@ -596,12 +603,13 @@ def create_app(settings):
         sharing_name = os.path.basename(path)
         logger.info(f"Creating proxied path for {username} with sharing name {sharing_name} and fsp_name {fsp_name} and path {path}")
         with db.get_db_session(settings.db_url) as session:
-            try:
-                new_path = db.create_proxied_path(session, username, sharing_name, fsp_name, path)
-                return _convert_proxied_path(new_path, settings.external_proxy_url)
-            except ValueError as e:
-                logger.error(f"Error creating proxied path: {e}")
-                raise HTTPException(status_code=400, detail=str(e))
+            with _get_user_context(username): # Necessary to validate the user can access the proxied path
+                try:
+                    new_path = db.create_proxied_path(session, username, sharing_name, fsp_name, path)
+                    return _convert_proxied_path(new_path, settings.external_proxy_url)
+                except ValueError as e:
+                    logger.error(f"Error creating proxied path: {e}")
+                    raise HTTPException(status_code=400, detail=str(e))
 
 
     @app.get("/api/proxied-path", response_model=ProxiedPathResponse,
@@ -635,12 +643,13 @@ def create_app(settings):
                                   sharing_name: Optional[str] = Query(default=None, description="The sharing path of the proxied path"),
                                   username: str = Depends(get_current_user)):
         with db.get_db_session(settings.db_url) as session:
-            try:
-                updated = db.update_proxied_path(session, username, sharing_key, new_path=path, new_sharing_name=sharing_name, new_fsp_name=fsp_name)
-                return _convert_proxied_path(updated, settings.external_proxy_url)
-            except ValueError as e:
-                logger.error(f"Error updating proxied path: {e}")
-                raise HTTPException(status_code=400, detail=str(e))
+            with _get_user_context(username): # Necessary to validate the user can access the proxied path
+                try:
+                    updated = db.update_proxied_path(session, username, sharing_key, new_path=path, new_sharing_name=sharing_name, new_fsp_name=fsp_name)
+                    return _convert_proxied_path(updated, settings.external_proxy_url)
+                except ValueError as e:
+                    logger.error(f"Error updating proxied path: {e}")
+                    raise HTTPException(status_code=400, detail=str(e))
 
 
     @app.delete("/api/proxied-path/{sharing_key}", description="Delete a proxied path by sharing key")
@@ -713,44 +722,11 @@ def create_app(settings):
 
     def _get_filestore(path_name: str):
         """Get a filestore for the given path name."""
-        # Get file share path from database or settings
-        file_share_mounts = settings.file_share_mounts
-        fsp = None
-
-        if file_share_mounts:
-            for path in file_share_mounts:
-                name = slugify_path(path)
-                if name == path_name:
-                    fsp = FileSharePath(
-                        name=name,
-                        zone='Local',
-                        group='local',
-                        storage='local',
-                        mount_path=path,
-                        mac_path=path,
-                        windows_path=path,
-                        linux_path=path,
-                    )
-                    break
-        else:
-            with db.get_db_session(settings.db_url) as session:
-                db_paths = db.get_all_paths(session)
-                for path in db_paths:
-                    if path.name == path_name:
-                        fsp = FileSharePath(
-                            name=path.name,
-                            zone=path.zone,
-                            group=path.group,
-                            storage=path.storage,
-                            mount_path=path.mount_path,
-                            mac_path=path.mac_path,
-                            windows_path=path.windows_path,
-                            linux_path=path.linux_path,
-                        )
-                        break
-
-        if fsp is None:
-            return None, f"File share path '{path_name}' not found"
+        # Get file share path using centralized function and filter for the requested path
+        with db.get_db_session(settings.db_url) as session:
+            fsp = db.get_file_share_path(session, path_name)
+            if fsp is None:
+                return None, f"File share path '{path_name}' not found"
 
         # Create a filestore for the file share path
         filestore = _get_mounted_filestore(fsp)
@@ -765,25 +741,23 @@ def create_app(settings):
     async def get_profile(username: str = Depends(get_current_user)):
         """Get the current user's profile"""
         with _get_user_context(username):
-            home_directory_path = os.path.expanduser(f"~{username}")
-            home_directory_name = os.path.basename(home_directory_path)
-            home_parent = os.path.dirname(home_directory_path)
-
+            
             # Find matching file share path for home directory
-            home_fsp_name = None
-            file_share_mounts = settings.file_share_mounts
-            if file_share_mounts:
-                for path in file_share_mounts:
-                    if path == home_parent:
-                        home_fsp_name = slugify_path(path)
-                        break
-            else:
-                with db.get_db_session(settings.db_url) as session:
-                    paths = db.get_all_paths(session)
-                    for fsp in paths:
-                        if fsp.mount_path == home_parent:
-                            home_fsp_name = fsp.name
-                            break
+            with db.get_db_session(settings.db_url) as session:
+                paths = db.get_file_share_paths(session)
+
+                # First, check if there's a "home" FSP (for ~/ paths)
+                home_fsp = next((fsp for fsp in paths if fsp.mount_path in ('~', '~/')), None)
+                if home_fsp:
+                    home_directory_name = "."
+                else:
+                    # If no "home" FSP exists, fall back to finding by mount path
+                    home_directory_path = os.path.expanduser(f"~{username}")
+                    home_parent = os.path.dirname(home_directory_path)
+                    home_fsp = next((fsp for fsp in paths if fsp.mount_path == home_parent), None)
+                    home_directory_name = os.path.basename(home_directory_path)
+
+                home_fsp_name = home_fsp.name if home_fsp else None
 
             # Get user groups
             user_groups = []
@@ -1080,6 +1054,7 @@ def create_app(settings):
                 username=username,
                 email=None,  # No email for simple auth
                 expires_at=expires_at,
+                session_secret_key=settings.session_secret_key,
                 okta_access_token=None,
                 okta_id_token=None
             )
